diff -r 5432b55a2b87 doc/man/doveconf.1.in
--- a/doc/man/doveconf.1.in	Fri Jan 31 02:12:30 2014 +0100
+++ b/doc/man/doveconf.1.in	Thu Mar 13 16:31:12 2014 +0100
@@ -120,6 +120,20 @@
 Show settings with non\-default values and explicitly set default values.
 .\"---------------------------------
 .TP
+.B \-P
+In modes that dump settings, e.g. simplified, section or human redable,
+by default, values of keys, that end with
+.B _password
+are  displayed as "
+.B <hidden>
+", in order to hide sensitive information. One
+.B -P
+shows the passwords, with two
+.B -P\ -P
+the whole line is suppressed, in order to also hide the fact,
+that a password is specified at all.
+.\"---------------------------------
+.TP
 .B \-S
 Dump settings in simplified machine parsable/readable format.
 .\"---------------------------------
@@ -195,4 +209,4 @@
 .BR doveadm (1),
 .BR dovecot (1),
 .BR dovecot\-lda (1),
-.BR dsync (1)
\ No newline at end of file
+.BR dsync (1)
diff -r 5432b55a2b87 src/config/doveconf.c
--- a/src/config/doveconf.c	Fri Jan 31 02:12:30 2014 +0100
+++ b/src/config/doveconf.c	Thu Mar 13 16:31:12 2014 +0100
@@ -46,6 +46,18 @@
 #define UNIQUE_KEY_SUFFIX "\xff"
 
 static const char *indent_str = "                              !!!!";
+static int hide_passwords = 1;
+
+const char password_string[] = "_password";
+const char password_hide_string[] = "<hidden>";
+/* Does key end with password? */
+static int
+key_is_password(const char * const key)
+{	size_t len = strlen(key);
+	return len >= sizeof(password_string)-1
+	 && memcmp(key + len - (sizeof(password_string)-1), password_string, sizeof(password_string)) == 0;
+}
+
 
 static void
 config_request_get_strings(const char *key, const char *value,
@@ -54,6 +66,12 @@
 	struct config_dump_human_context *ctx = context;
 	const char *p;
 
+	if(hide_passwords && key_is_password(key)) {
+		if(hide_passwords < 0)	/* skip this setting */
+			return;
+		value = password_hide_string;
+	}
+
 	switch (type) {
 	case CONFIG_KEY_NORMAL:
 		value = p_strdup_printf(ctx->pool, "%s=%s", key, value);
@@ -493,6 +511,12 @@
 	char **setting_name_filters = context;
 	unsigned int i, filter_len;
 
+	if(hide_passwords && key_is_password(key)) {
+		if(hide_passwords < 0)	/* skip this setting */
+			return;
+		value = password_hide_string;
+	}
+
 	if (setting_name_filters == NULL) {
 		printf("%s=%s\n", key, value);
 		return;
@@ -716,7 +740,7 @@
 	memset(&filter, 0, sizeof(filter));
 	master_service = master_service_init("config",
 					     MASTER_SERVICE_FLAG_STANDALONE,
-					     &argc, &argv, "adf:hHm:nNpexS");
+					     &argc, &argv, "adf:hHm:nNpexSP");
 	orig_config_path = master_service_get_config_path(master_service);
 
 	i_set_failure_prefix("doveconf: ");
@@ -757,6 +781,9 @@
 		case 'S':
 			simple_output = TRUE;
 			break;
+		case 'P':
+			--hide_passwords;
+			break;
 		case 'x':
 			expand_vars = TRUE;
 			break;
@@ -819,6 +846,7 @@
 		   using doveconf to lookup settings for things like install or
 		   uninstall scripts where the configuration might
 		   (temporarily) not be fully usable */
+		hide_passwords = 0;
 		ret = 0;
 		for (i = 0; setting_name_filters[i] != NULL; i++) {
 			if (config_dump_one(&filter, hide_key, scope,
@@ -840,6 +868,7 @@
 	} else {
 		struct config_export_context *ctx;
 
+		hide_passwords = 0;
 		env_put("DOVECONF_ENV=1");
 		ctx = config_export_init(wanted_modules, CONFIG_DUMP_SCOPE_SET,
 					 CONFIG_DUMP_FLAG_CHECK_SETTINGS,
